.. _spkg_sagemath_schemes:

=====================================================================================================================================================================
sagemath_schemes: Schemes, varieties, elliptic curves, algebraic Riemann surfaces, modular forms, arithmetic dynamics
=====================================================================================================================================================================


This pip-installable distribution ``passagemath-schemes`` is a distribution of a part of the Sage Library.  It provides a subset of the modules of the Sage library ("sagelib", ``passagemath-standard``).


What is included
----------------

* `Ideals and Varieties <https://passagemath.org/docs/latest/html/en/reference/polynomial_rings/sage/rings/polynomial/multi_polynomial_ideal.html>`_

* `Schemes <https://passagemath.org/docs/latest/html/en/reference/schemes/index.html>`_

* `Plane and Space Curves <https://passagemath.org/docs/latest/html/en/reference/curves/index.html>`_

* `Elliptic and Hyperelliptic Curves <https://passagemath.org/docs/latest/html/en/reference/arithmetic_curves/index.html>`_

* `Modular Forms <https://passagemath.org/docs/latest/html/en/reference/modfrm/index.html>`_

* `Modular Symbols <https://passagemath.org/docs/latest/html/en/reference/modsym/index.html>`_

* `Modular Abelian Varieties <https://passagemath.org/docs/latest/html/en/reference/modabvar/index.html>`_

* `Arithmetic Dynamical Systems <https://passagemath.org/docs/latest/html/en/reference/dynamics/index.html#arithmetic-dynamical-systems>`_


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_elliptic_curves`
- :ref:`spkg_fpylll`
- :ref:`spkg_gmp`
- :ref:`spkg_gmpy2`
- :ref:`spkg_memory_allocator`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfr`
- :ref:`spkg_pkgconf`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_flint`
- :ref:`spkg_sagemath_modules`
- :ref:`spkg_sagemath_polyhedra`
- :ref:`spkg_sagemath_singular`
- :ref:`spkg_scipy`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.8.2.rc1

version_requirements.txt::

    passagemath-schemes == 10.8.2rc1

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-schemes==10.8.2rc1

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_schemes


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
